Module base64

Module base64 

base64 decoder/encoder using safe alphabet according to: https://datatracker.ietf.org/doc/html/rfc4648#section-4 https://datatracker.ietf.org/doc/html/rfc4648#section-5

Encoding is implementing with padding at the end (add 1 or 2 ‘=’ if necessary to make the data a multiple of 4) Decoding does not require the data to be padded, that is it makes no difference if padding is present or not

Functions

decode
encode