#[non_exhaustive]pub enum FromStrRadixErrKind {
InvalidCharacter,
InvalidLength,
UnsupportedRadix,
}Expand description
A list of error categories encountered when parsing numbers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidCharacter
A character in the input string is not valid for the given radix.
InvalidLength
The input length is not valid for the given radix.
UnsupportedRadix
The given radix is not supported.