pub struct BlobsBundle {
pub blobs: Vec<Blob>,
pub commitments: Vec<Commitment>,
pub proofs: Vec<Proof>,
pub version: u8,
}Expand description
Struct containing all the blobs for a blob transaction, along with the corresponding commitments and proofs
Fields
blobs: Vec<Blob>commitments: Vec<Commitment>proofs: Vec<Proof>version: u8Implementations
Sourceimpl BlobsBundle
impl BlobsBundle
pub fn empty() -> Self
pub fn is_empty(&self) -> bool
pub fn generate_versioned_hashes(&self) -> Vec<H256>
Sourcepub fn get_blob_tuple_by_index(&self, index: usize) -> Option<BlobTuple>
pub fn get_blob_tuple_by_index(&self, index: usize) -> Option<BlobTuple>
Given an index returns all or nothing BlobTuple if either of the commitment, proof or
blob is not found then it will return None instead of Partial data.
pub fn validate_blob_commitment_hashes( &self, blob_versioned_hashes: &[H256], ) -> Result<(), BlobsBundleError>