pub enum ProofData<I> {
ProverSetup {
prover_type: ProverType,
payload: Bytes,
},
ProverSetupACK,
InputRequest {
commit_hash: String,
prover_type: ProverType,
},
VersionMismatch,
ProverTypeNotNeeded {
prover_type: ProverType,
},
InputResponse {
id: Option<u64>,
input: Option<I>,
format: Option<ProofFormat>,
},
ProofSubmit {
id: u64,
proof: ProverOutput,
},
ProofSubmitACK {
id: u64,
},
}Expand description
Generic enum for the ProverServer <–> ProverClient Communication Protocol.
The type parameter I represents the input type sent from server to prover:
- L2 uses
ProverInputData - L1 uses
ProgramInput
Variants
ProverSetup
The client performs any needed setup steps (e.g. key registration).
ProverSetupACK
The Server acknowledges the receipt of the setup and its completion.
InputRequest
The Client requests work from the coordinator. The commit hash ensures client and server are compatible. The prover_type tells the coordinator which backend the client runs, so it can skip work items that already have a proof for that type.
VersionMismatch
The Server responds with VersionMismatch when the prover’s code version does not match the version needed to prove the next work item.
ProverTypeNotNeeded
The Server responds with ProverTypeNotNeeded when the connecting prover’s backend type is not in the set of required proof types for this deployment.
Fields
prover_type: ProverTypeInputResponse
The Server responds with an InputResponse containing the input data. If all fields are None, the Client knows no work is available.
ProofSubmit
The Client submits the proof generated by the prover for the specified id.
ProofSubmitACK
The Server acknowledges the receipt of the proof and updates its state.
Implementations
Sourceimpl<I> ProofData<I>
impl<I> ProofData<I>
pub fn prover_setup(prover_type: ProverType, payload: Bytes) -> Self
pub fn prover_setup_ack() -> Self
pub fn input_request(commit_hash: String, prover_type: ProverType) -> Self
pub fn version_mismatch() -> Self
pub fn input_response(id: u64, input: I, format: ProofFormat) -> Self
pub fn empty_input_response() -> Self
pub fn proof_submit(id: u64, proof: ProverOutput) -> Self
pub fn proof_submit_ack(id: u64) -> Self