pub struct AccountStateSlimCodec(pub AccountState);Expand description
A slim codec for an AccountState.
The slim codec will optimize both the storage root and the code hash’s encoding so that it does not take space when empty.
The correct way to use it is to wrap the AccountState and encode it using this codec, and
not to store the codec as a field in a struct.
Tuple Fields
0: AccountStateTrait Implementations
Sourceimpl Clone for AccountStateSlimCodec
impl Clone for AccountStateSlimCodec
Sourcefn clone(&self) -> AccountStateSlimCodec
fn clone(&self) -> AccountStateSlimCodec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AccountStateSlimCodec
Sourceimpl Debug for AccountStateSlimCodec
impl Debug for AccountStateSlimCodec
Sourceimpl Default for AccountStateSlimCodec
impl Default for AccountStateSlimCodec
Sourcefn default() -> AccountStateSlimCodec
fn default() -> AccountStateSlimCodec
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AccountStateSlimCodec
impl PartialEq for AccountStateSlimCodec
Sourcefn eq(&self, other: &AccountStateSlimCodec) -> bool
fn eq(&self, other: &AccountStateSlimCodec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RLPDecode for AccountStateSlimCodec
impl RLPDecode for AccountStateSlimCodec
fn decode_unfinished(rlp: &[u8]) -> Result<(Self, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for AccountStateSlimCodec
impl RLPEncode for AccountStateSlimCodec
impl StructuralPartialEq for AccountStateSlimCodec