pub struct BlobSchedule {
pub cancun: ForkBlobSchedule,
pub prague: ForkBlobSchedule,
pub osaka: ForkBlobSchedule,
pub bpo1: ForkBlobSchedule,
pub bpo2: ForkBlobSchedule,
pub bpo3: Option<ForkBlobSchedule>,
pub bpo4: Option<ForkBlobSchedule>,
pub bpo5: Option<ForkBlobSchedule>,
pub amsterdam: Option<ForkBlobSchedule>,
}Fields
cancun: ForkBlobScheduleprague: ForkBlobScheduleosaka: ForkBlobSchedulebpo1: ForkBlobSchedulebpo2: ForkBlobSchedulebpo3: Option<ForkBlobSchedule>bpo4: Option<ForkBlobSchedule>bpo5: Option<ForkBlobSchedule>amsterdam: Option<ForkBlobSchedule>Trait Implementations
Sourceimpl Archive for BlobSchedule
impl Archive for BlobSchedule
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBlobSchedule
type Archived = ArchivedBlobSchedule
The archived representation of this type. Read more
Sourcetype Resolver = BlobScheduleResolver
type Resolver = BlobScheduleResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for BlobSchedule
impl Clone for BlobSchedule
Sourcefn clone(&self) -> BlobSchedule
fn clone(&self) -> BlobSchedule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BlobSchedule
Sourceimpl Debug for BlobSchedule
impl Debug for BlobSchedule
Sourceimpl Default for BlobSchedule
impl Default for BlobSchedule
Sourceimpl<'de> Deserialize<'de> for BlobSchedule
impl<'de> Deserialize<'de> for BlobSchedule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BlobSchedule, __D> for Archived<BlobSchedule>where
ForkBlobSchedule: Archive,
<ForkBlobSchedule as Archive>::Archived: Deserialize<ForkBlobSchedule, __D>,
Option<ForkBlobSchedule>: Archive,
<Option<ForkBlobSchedule> as Archive>::Archived: Deserialize<Option<ForkBlobSchedule>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<BlobSchedule, __D> for Archived<BlobSchedule>where
ForkBlobSchedule: Archive,
<ForkBlobSchedule as Archive>::Archived: Deserialize<ForkBlobSchedule, __D>,
Option<ForkBlobSchedule>: Archive,
<Option<ForkBlobSchedule> as Archive>::Archived: Deserialize<Option<ForkBlobSchedule>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BlobSchedule, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BlobSchedule, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for BlobSchedule
impl PartialEq for BlobSchedule
Sourcefn eq(&self, other: &BlobSchedule) -> bool
fn eq(&self, other: &BlobSchedule) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BlobSchedule
impl Serialize for BlobSchedule
impl StructuralPartialEq for BlobSchedule