ChainConfig

Struct ChainConfig 

pub struct ChainConfig {
Show 33 fields pub chain_id: u64, pub homestead_block: Option<u64>, pub dao_fork_block: Option<u64>, pub dao_fork_support: bool, pub eip150_block: Option<u64>, pub eip155_block: Option<u64>, pub eip158_block: Option<u64>, pub byzantium_block: Option<u64>, pub constantinople_block: Option<u64>, pub petersburg_block: Option<u64>, pub istanbul_block: Option<u64>, pub muir_glacier_block: Option<u64>, pub berlin_block: Option<u64>, pub london_block: Option<u64>, pub arrow_glacier_block: Option<u64>, pub gray_glacier_block: Option<u64>, pub merge_netsplit_block: Option<u64>, pub shanghai_time: Option<u64>, pub cancun_time: Option<u64>, pub prague_time: Option<u64>, pub verkle_time: Option<u64>, pub osaka_time: Option<u64>, pub bpo1_time: Option<u64>, pub bpo2_time: Option<u64>, pub bpo3_time: Option<u64>, pub bpo4_time: Option<u64>, pub bpo5_time: Option<u64>, pub amsterdam_time: Option<u64>, pub terminal_total_difficulty: Option<u128>, pub terminal_total_difficulty_passed: bool, pub blob_schedule: BlobSchedule, pub deposit_contract_address: Address, pub enable_verkle_at_genesis: bool,
}
Blockchain settings defined per block

Fields

chain_id: u64

Current chain identifier

homestead_block: Option<u64>

Block numbers for the block where each fork was activated (None = no fork, 0 = fork is already active)

dao_fork_block: Option<u64>dao_fork_support: bool

Whether the node supports or opposes the DAO hard-fork

eip150_block: Option<u64>eip155_block: Option<u64>eip158_block: Option<u64>byzantium_block: Option<u64>constantinople_block: Option<u64>petersburg_block: Option<u64>istanbul_block: Option<u64>muir_glacier_block: Option<u64>berlin_block: Option<u64>london_block: Option<u64>arrow_glacier_block: Option<u64>gray_glacier_block: Option<u64>merge_netsplit_block: Option<u64>shanghai_time: Option<u64>

Timestamp at which each fork was activated (None = no fork, 0 = fork is already active)

cancun_time: Option<u64>prague_time: Option<u64>verkle_time: Option<u64>osaka_time: Option<u64>bpo1_time: Option<u64>bpo2_time: Option<u64>bpo3_time: Option<u64>bpo4_time: Option<u64>bpo5_time: Option<u64>amsterdam_time: Option<u64>terminal_total_difficulty: Option<u128>

Amount of total difficulty reached by the network that triggers the consensus upgrade.

terminal_total_difficulty_passed: bool

Network has already passed the terminal total difficult

blob_schedule: BlobScheduledeposit_contract_address: Addressenable_verkle_at_genesis: bool

Implementations

Source

impl ChainConfig

pub fn is_amsterdam_activated(&self, block_timestamp: u64) -> bool

pub fn is_bpo5_activated(&self, block_timestamp: u64) -> bool

pub fn is_bpo4_activated(&self, block_timestamp: u64) -> bool

pub fn is_bpo3_activated(&self, block_timestamp: u64) -> bool

pub fn is_bpo2_activated(&self, block_timestamp: u64) -> bool

pub fn is_bpo1_activated(&self, block_timestamp: u64) -> bool

pub fn is_osaka_activated(&self, block_timestamp: u64) -> bool

pub fn is_prague_activated(&self, block_timestamp: u64) -> bool

pub fn is_shanghai_activated(&self, block_timestamp: u64) -> bool

pub fn is_cancun_activated(&self, block_timestamp: u64) -> bool

pub fn is_istanbul_activated(&self, block_number: BlockNumber) -> bool

pub fn is_london_activated(&self, block_number: BlockNumber) -> bool

pub fn is_eip155_activated(&self, block_number: BlockNumber) -> bool

pub fn display_config(&self) -> String

pub fn get_fork(&self, block_timestamp: u64) -> Fork

pub fn get_fork_blob_schedule( &self, block_timestamp: u64, ) -> Option<ForkBlobSchedule>

pub fn fork(&self, block_timestamp: u64) -> Fork

pub fn next_fork(&self, block_timestamp: u64) -> Option<Fork>

pub fn get_last_scheduled_fork(&self) -> Fork

pub fn get_activation_timestamp_for_fork(&self, fork: Fork) -> Option<u64>

pub fn get_blob_schedule_for_fork(&self, fork: Fork) -> Option<ForkBlobSchedule>

pub fn gather_forks(&self, genesis_header: BlockHeader) -> (Vec<u64>, Vec<u64>)