pub struct ForkBlobSchedule {
pub base_fee_update_fraction: u64,
pub max: u32,
pub target: u32,
}Fields
base_fee_update_fraction: u64max: u32target: u32Trait Implementations
Sourceimpl Archive for ForkBlobSchedule
impl Archive for ForkBlobSchedule
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedForkBlobSchedule
type Archived = ArchivedForkBlobSchedule
The archived representation of this type. Read more
Sourcetype Resolver = ForkBlobScheduleResolver
type Resolver = ForkBlobScheduleResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ForkBlobSchedule
impl Clone for ForkBlobSchedule
Sourcefn clone(&self) -> ForkBlobSchedule
fn clone(&self) -> ForkBlobSchedule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ForkBlobSchedule
Sourceimpl Debug for ForkBlobSchedule
impl Debug for ForkBlobSchedule
Sourceimpl Default for ForkBlobSchedule
impl Default for ForkBlobSchedule
Sourcefn default() -> ForkBlobSchedule
fn default() -> ForkBlobSchedule
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ForkBlobSchedule
impl<'de> Deserialize<'de> for ForkBlobSchedule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ForkBlobSchedule, __D> for Archived<ForkBlobSchedule>
impl<__D: Fallible + ?Sized> Deserialize<ForkBlobSchedule, __D> for Archived<ForkBlobSchedule>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ForkBlobSchedule, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ForkBlobSchedule, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for ForkBlobSchedule
impl PartialEq for ForkBlobSchedule
Sourcefn eq(&self, other: &ForkBlobSchedule) -> bool
fn eq(&self, other: &ForkBlobSchedule) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ForkBlobSchedule
impl Serialize for ForkBlobSchedule
impl StructuralPartialEq for ForkBlobSchedule