pub struct Receipt {
pub tx_type: TxType,
pub succeeded: bool,
pub cumulative_gas_used: u64,
pub logs: Vec<Log>,
}Expand description
Result of a transaction
Fields
tx_type: TxTypesucceeded: boolcumulative_gas_used: u64Cumulative gas used by this and all previous transactions in the block. This is always post-refund gas. Note: Block-level gas accounting (pre-refund for EIP-7778) uses BlockExecutionResult::block_gas_used.
logs: Vec<Log>Implementations
Sourceimpl Receipt
impl Receipt
pub fn new( tx_type: TxType, succeeded: bool, cumulative_gas_used: u64, logs: Vec<Log>, ) -> Self
pub fn encode_inner(&self) -> Vec<u8> ⓘ
pub fn encode_inner_with_bloom(&self, crypto: &dyn Crypto) -> Vec<u8> ⓘ
Sourcepub fn encode_inner_with_precomputed_bloom(&self, bloom: Bloom) -> Vec<u8> ⓘ
pub fn encode_inner_with_precomputed_bloom(&self, bloom: Bloom) -> Vec<u8> ⓘ
Like Self::encode_inner_with_bloom but takes an already-computed bloom, so
callers that also need the bloom for other purposes (e.g. the aggregate header
logs_bloom) don’t recompute it.