pub struct Withdrawal {
pub index: u64,
pub validator_index: u64,
pub address: Address,
pub amount: u64,
}Fields
index: u64validator_index: u64address: Addressamount: u64Trait Implementations
Sourceimpl Archive for Withdrawal
impl Archive for Withdrawal
Sourcetype Archived = ArchivedWithdrawal
type Archived = ArchivedWithdrawal
The archived representation of this type. Read more
Sourcetype Resolver = WithdrawalResolver
type Resolver = WithdrawalResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for Withdrawal
impl Clone for Withdrawal
Sourcefn clone(&self) -> Withdrawal
fn clone(&self) -> Withdrawal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Withdrawal
impl Debug for Withdrawal
Sourceimpl<'de> Deserialize<'de> for Withdrawal
impl<'de> Deserialize<'de> for Withdrawal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Withdrawal, __D> for Archived<Withdrawal>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Withdrawal, __D> for Archived<Withdrawal>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<Withdrawal, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<Withdrawal, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for Withdrawal
Sourceimpl PartialEq for Withdrawal
impl PartialEq for Withdrawal
Sourcefn eq(&self, other: &Withdrawal) -> bool
fn eq(&self, other: &Withdrawal) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RLPDecode for Withdrawal
impl RLPDecode for Withdrawal
fn decode_unfinished(rlp: &[u8]) -> Result<(Self, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for Withdrawal
impl RLPEncode for Withdrawal
Sourceimpl Serialize for Withdrawal
impl Serialize for Withdrawal
impl StructuralPartialEq for Withdrawal