pub enum P2PTransaction {
LegacyTransaction(LegacyTransaction),
EIP2930Transaction(EIP2930Transaction),
EIP1559Transaction(EIP1559Transaction),
EIP4844TransactionWithBlobs(WrappedEIP4844Transaction),
EIP7702Transaction(EIP7702Transaction),
FeeTokenTransaction(FeeTokenTransaction),
}Expand description
The same as a Transaction enum, only that blob transactions are in wrapped format, including the blobs bundle. PrivilegedL2Transaction is not included as it is not expected to be sent over P2P.
Variants
LegacyTransaction(LegacyTransaction)
EIP2930Transaction(EIP2930Transaction)
EIP1559Transaction(EIP1559Transaction)
EIP4844TransactionWithBlobs(WrappedEIP4844Transaction)
EIP7702Transaction(EIP7702Transaction)
FeeTokenTransaction(FeeTokenTransaction)
Implementations
Sourceimpl P2PTransaction
impl P2PTransaction
pub fn tx_type(&self) -> TxType
pub fn encode_canonical(&self, buf: &mut dyn BufMut)
pub fn encode_canonical_to_vec(&self) -> Vec<u8> ⓘ
pub fn compute_hash(&self) -> H256