pub struct EIP4844Transaction {Show 17 fields
pub chain_id: u64,
pub nonce: u64,
pub max_priority_fee_per_gas: u64,
pub max_fee_per_gas: u64,
pub gas: u64,
pub to: Address,
pub value: U256,
pub data: Bytes,
pub access_list: AccessList,
pub max_fee_per_blob_gas: U256,
pub blob_versioned_hashes: Vec<H256>,
pub signature_y_parity: bool,
pub signature_r: U256,
pub signature_s: U256,
pub inner_hash: OnceCell<H256>,
pub sender_cache: OnceCell<Address>,
pub cached_canonical: OnceCell<Vec<u8>>,
}Fields
chain_id: u64nonce: u64max_priority_fee_per_gas: u64max_fee_per_gas: u64gas: u64to: Addressvalue: U256data: Bytesaccess_list: AccessListmax_fee_per_blob_gas: U256blob_versioned_hashes: Vec<H256>signature_y_parity: boolsignature_r: U256signature_s: U256inner_hash: OnceCell<H256>sender_cache: OnceCell<Address>cached_canonical: OnceCell<Vec<u8>>Trait Implementations
Sourceimpl Archive for EIP4844Transactionwhere
u64: Archive,
H160Wrapper: ArchiveWith<Address>,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
Map<H256Wrapper>: ArchiveWith<Vec<H256>>,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
impl Archive for EIP4844Transactionwhere
u64: Archive,
H160Wrapper: ArchiveWith<Address>,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
Map<H256Wrapper>: ArchiveWith<Vec<H256>>,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
Sourcetype Archived = ArchivedEIP4844Transaction
type Archived = ArchivedEIP4844Transaction
The archived representation of this type. Read more
Sourcetype Resolver = EIP4844TransactionResolver
type Resolver = EIP4844TransactionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for EIP4844Transaction
impl Clone for EIP4844Transaction
Sourcefn clone(&self) -> EIP4844Transaction
fn clone(&self) -> EIP4844Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EIP4844Transaction
impl Debug for EIP4844Transaction
Sourceimpl Default for EIP4844Transaction
impl Default for EIP4844Transaction
Sourcefn default() -> EIP4844Transaction
fn default() -> EIP4844Transaction
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EIP4844Transaction
impl<'de> Deserialize<'de> for EIP4844Transaction
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EIP4844Transaction, __D> for Archived<EIP4844Transaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
Map<H256Wrapper>: ArchiveWith<Vec<H256>> + DeserializeWith<<Map<H256Wrapper> as ArchiveWith<Vec<H256>>>::Archived, Vec<H256>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<EIP4844Transaction, __D> for Archived<EIP4844Transaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
Map<H256Wrapper>: ArchiveWith<Vec<H256>> + DeserializeWith<<Map<H256Wrapper> as ArchiveWith<Vec<H256>>>::Archived, Vec<H256>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EIP4844Transaction, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EIP4844Transaction, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for EIP4844Transaction
Sourceimpl From<EIP4844Transaction> for GenericTransaction
impl From<EIP4844Transaction> for GenericTransaction
Sourcefn from(value: EIP4844Transaction) -> Self
fn from(value: EIP4844Transaction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for EIP4844Transaction
impl PartialEq for EIP4844Transaction
Sourcefn eq(&self, other: &EIP4844Transaction) -> bool
fn eq(&self, other: &EIP4844Transaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PayloadRLPEncode for EIP4844Transaction
impl PayloadRLPEncode for EIP4844Transaction
fn encode_payload(&self, buf: &mut dyn BufMut)
fn encode_payload_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl RLPDecode for EIP4844Transaction
impl RLPDecode for EIP4844Transaction
fn decode_unfinished( rlp: &[u8], ) -> Result<(EIP4844Transaction, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for EIP4844Transaction
impl RLPEncode for EIP4844Transaction
Sourceimpl Serialize for EIP4844Transaction
impl Serialize for EIP4844Transaction
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for EIP4844Transactionwhere
u64: Serialize<__S>,
H160Wrapper: SerializeWith<Address, __S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
Map<H256Wrapper>: SerializeWith<Vec<H256>, __S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for EIP4844Transactionwhere
u64: Serialize<__S>,
H160Wrapper: SerializeWith<Address, __S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
Map<H256Wrapper>: SerializeWith<Vec<H256>, __S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl StructuralPartialEq for EIP4844Transaction
Sourceimpl TryFrom<GenericTransaction> for EIP4844Transaction
impl TryFrom<GenericTransaction> for EIP4844Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.