pub struct EIP7702Transaction {Show 16 fields
pub chain_id: u64,
pub nonce: u64,
pub max_priority_fee_per_gas: u64,
pub max_fee_per_gas: u64,
pub gas_limit: u64,
pub to: Address,
pub value: U256,
pub data: Bytes,
pub access_list: AccessList,
pub authorization_list: AuthorizationList,
pub signature_y_parity: bool,
pub signature_r: U256,
pub signature_s: U256,
pub inner_hash: OnceCell<H256>,
pub sender_cache: OnceCell<Address>,
pub cached_canonical: OnceCell<Vec<u8>>,
}Fields
chain_id: u64nonce: u64max_priority_fee_per_gas: u64max_fee_per_gas: u64gas_limit: u64to: Addressvalue: U256data: Bytesaccess_list: AccessListsignature_y_parity: boolsignature_r: U256signature_s: U256inner_hash: OnceCell<H256>sender_cache: OnceCell<Address>cached_canonical: OnceCell<Vec<u8>>Trait Implementations
Sourceimpl Archive for EIP7702Transactionwhere
u64: Archive,
H160Wrapper: ArchiveWith<Address>,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
AuthorizationList: Archive,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
impl Archive for EIP7702Transactionwhere
u64: Archive,
H160Wrapper: ArchiveWith<Address>,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
AuthorizationList: Archive,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
Sourcetype Archived = ArchivedEIP7702Transaction
type Archived = ArchivedEIP7702Transaction
The archived representation of this type. Read more
Sourcetype Resolver = EIP7702TransactionResolver
type Resolver = EIP7702TransactionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for EIP7702Transaction
impl Clone for EIP7702Transaction
Sourcefn clone(&self) -> EIP7702Transaction
fn clone(&self) -> EIP7702Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EIP7702Transaction
impl Debug for EIP7702Transaction
Sourceimpl Default for EIP7702Transaction
impl Default for EIP7702Transaction
Sourcefn default() -> EIP7702Transaction
fn default() -> EIP7702Transaction
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EIP7702Transaction
impl<'de> Deserialize<'de> for EIP7702Transaction
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EIP7702Transaction, __D> for Archived<EIP7702Transaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
AuthorizationList: Archive,
<AuthorizationList as Archive>::Archived: Deserialize<AuthorizationList, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<EIP7702Transaction, __D> for Archived<EIP7702Transaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
AuthorizationList: Archive,
<AuthorizationList as Archive>::Archived: Deserialize<AuthorizationList, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EIP7702Transaction, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EIP7702Transaction, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for EIP7702Transaction
Sourceimpl From<EIP7702Transaction> for GenericTransaction
impl From<EIP7702Transaction> for GenericTransaction
Sourcefn from(value: EIP7702Transaction) -> Self
fn from(value: EIP7702Transaction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for EIP7702Transaction
impl PartialEq for EIP7702Transaction
Sourcefn eq(&self, other: &EIP7702Transaction) -> bool
fn eq(&self, other: &EIP7702Transaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PayloadRLPEncode for EIP7702Transaction
impl PayloadRLPEncode for EIP7702Transaction
fn encode_payload(&self, buf: &mut dyn BufMut)
fn encode_payload_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl RLPDecode for EIP7702Transaction
impl RLPDecode for EIP7702Transaction
fn decode_unfinished( rlp: &[u8], ) -> Result<(EIP7702Transaction, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for EIP7702Transaction
impl RLPEncode for EIP7702Transaction
Sourceimpl Serialize for EIP7702Transaction
impl Serialize for EIP7702Transaction
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for EIP7702Transactionwhere
u64: Serialize<__S>,
H160Wrapper: SerializeWith<Address, __S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
AuthorizationList: Serialize<__S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for EIP7702Transactionwhere
u64: Serialize<__S>,
H160Wrapper: SerializeWith<Address, __S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
AuthorizationList: Serialize<__S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl StructuralPartialEq for EIP7702Transaction
Sourceimpl TryFrom<GenericTransaction> for EIP7702Transaction
impl TryFrom<GenericTransaction> for EIP7702Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.