pub struct FeeTokenTransaction {Show 16 fields
pub chain_id: u64,
pub nonce: u64,
pub max_priority_fee_per_gas: u64,
pub max_fee_per_gas: u64,
pub gas_limit: u64,
pub to: TxKind,
pub value: U256,
pub data: Bytes,
pub access_list: AccessList,
pub fee_token: Address,
pub signature_y_parity: bool,
pub signature_r: U256,
pub signature_s: U256,
pub inner_hash: OnceCell<H256>,
pub sender_cache: OnceCell<Address>,
pub cached_canonical: OnceCell<Vec<u8>>,
}Fields
chain_id: u64nonce: u64max_priority_fee_per_gas: u64max_fee_per_gas: u64gas_limit: u64to: TxKindvalue: U256data: Bytesaccess_list: AccessListfee_token: Addresssignature_y_parity: boolsignature_r: U256signature_s: U256inner_hash: OnceCell<H256>sender_cache: OnceCell<Address>cached_canonical: OnceCell<Vec<u8>>Trait Implementations
Sourceimpl Archive for FeeTokenTransactionwhere
u64: Archive,
TxKind: Archive,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
H160Wrapper: ArchiveWith<Address>,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
impl Archive for FeeTokenTransactionwhere
u64: Archive,
TxKind: Archive,
U256Wrapper: ArchiveWith<U256>,
BytesWrapper: ArchiveWith<Bytes>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList>,
H160Wrapper: ArchiveWith<Address>,
bool: Archive,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>> + ArchiveWith<OnceCell<Vec<u8>>>,
Sourcetype Archived = ArchivedFeeTokenTransaction
type Archived = ArchivedFeeTokenTransaction
The archived representation of this type. Read more
Sourcetype Resolver = FeeTokenTransactionResolver
type Resolver = FeeTokenTransactionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for FeeTokenTransaction
impl Clone for FeeTokenTransaction
Sourcefn clone(&self) -> FeeTokenTransaction
fn clone(&self) -> FeeTokenTransaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeeTokenTransaction
impl Debug for FeeTokenTransaction
Sourceimpl Default for FeeTokenTransaction
impl Default for FeeTokenTransaction
Sourcefn default() -> FeeTokenTransaction
fn default() -> FeeTokenTransaction
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FeeTokenTransaction
impl<'de> Deserialize<'de> for FeeTokenTransaction
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FeeTokenTransaction, __D> for Archived<FeeTokenTransaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
TxKind: Archive,
<TxKind as Archive>::Archived: Deserialize<TxKind, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<FeeTokenTransaction, __D> for Archived<FeeTokenTransaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
TxKind: Archive,
<TxKind as Archive>::Archived: Deserialize<TxKind, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Map<AccessListItemWrapper>: ArchiveWith<AccessList> + DeserializeWith<<Map<AccessListItemWrapper> as ArchiveWith<AccessList>>::Archived, AccessList, __D>,
H160Wrapper: ArchiveWith<Address> + DeserializeWith<<H160Wrapper as ArchiveWith<Address>>::Archived, Address, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D> + ArchiveWith<OnceCell<Vec<u8>>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Vec<u8>>>>::Archived, OnceCell<Vec<u8>>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FeeTokenTransaction, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FeeTokenTransaction, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for FeeTokenTransaction
Sourceimpl From<FeeTokenTransaction> for GenericTransaction
impl From<FeeTokenTransaction> for GenericTransaction
Sourcefn from(value: FeeTokenTransaction) -> Self
fn from(value: FeeTokenTransaction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for FeeTokenTransaction
impl PartialEq for FeeTokenTransaction
Sourcefn eq(&self, other: &FeeTokenTransaction) -> bool
fn eq(&self, other: &FeeTokenTransaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PayloadRLPEncode for FeeTokenTransaction
impl PayloadRLPEncode for FeeTokenTransaction
fn encode_payload(&self, buf: &mut dyn BufMut)
fn encode_payload_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl RLPDecode for FeeTokenTransaction
impl RLPDecode for FeeTokenTransaction
fn decode_unfinished( rlp: &[u8], ) -> Result<(FeeTokenTransaction, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for FeeTokenTransaction
impl RLPEncode for FeeTokenTransaction
Sourceimpl Serialize for FeeTokenTransaction
impl Serialize for FeeTokenTransaction
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for FeeTokenTransactionwhere
u64: Serialize<__S>,
TxKind: Serialize<__S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
H160Wrapper: SerializeWith<Address, __S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for FeeTokenTransactionwhere
u64: Serialize<__S>,
TxKind: Serialize<__S>,
U256Wrapper: SerializeWith<U256, __S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Map<AccessListItemWrapper>: SerializeWith<AccessList, __S>,
H160Wrapper: SerializeWith<Address, __S>,
bool: Serialize<__S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S> + SerializeWith<OnceCell<Vec<u8>>, __S>,
impl StructuralPartialEq for FeeTokenTransaction
Sourceimpl TryFrom<GenericTransaction> for FeeTokenTransaction
impl TryFrom<GenericTransaction> for FeeTokenTransaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.