pub struct GenericTransaction {Show 18 fields
pub type: TxType,
pub nonce: Option<u64>,
pub to: TxKind,
pub from: Address,
pub gas: Option<u64>,
pub value: U256,
pub gas_price: U256,
pub max_priority_fee_per_gas: Option<u64>,
pub max_fee_per_gas: Option<u64>,
pub max_fee_per_blob_gas: Option<U256>,
pub access_list: Vec<AccessListEntry>,
pub fee_token: Option<Address>,
pub authorization_list: Option<Vec<AuthorizationTupleEntry>>,
pub blob_versioned_hashes: Vec<H256>,
pub wrapper_version: Option<u8>,
pub blobs: Vec<Bytes>,
pub chain_id: Option<u64>,
pub input: Bytes,
}Expand description
Unsigned Transaction struct generic to all types which may not contain all required transaction fields Used to perform gas estimations and access list creation
Fields
type: TxTypenonce: Option<u64>to: TxKindfrom: Addressgas: Option<u64>value: U256gas_price: U256max_priority_fee_per_gas: Option<u64>max_fee_per_gas: Option<u64>max_fee_per_blob_gas: Option<U256>access_list: Vec<AccessListEntry>fee_token: Option<Address>blob_versioned_hashes: Vec<H256>wrapper_version: Option<u8>blobs: Vec<Bytes>chain_id: Option<u64>input: BytesTrait Implementations
Sourceimpl Clone for GenericTransaction
impl Clone for GenericTransaction
Sourcefn clone(&self) -> GenericTransaction
fn clone(&self) -> GenericTransaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenericTransaction
impl Debug for GenericTransaction
Sourceimpl Default for GenericTransaction
impl Default for GenericTransaction
Sourcefn default() -> GenericTransaction
fn default() -> GenericTransaction
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GenericTransaction
impl<'de> Deserialize<'de> for GenericTransaction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EIP1559Transaction> for GenericTransaction
impl From<EIP1559Transaction> for GenericTransaction
Sourcefn from(value: EIP1559Transaction) -> Self
fn from(value: EIP1559Transaction) -> Self
Converts to this type from the input type.
Sourceimpl From<EIP2930Transaction> for GenericTransaction
impl From<EIP2930Transaction> for GenericTransaction
Sourcefn from(value: EIP2930Transaction) -> Self
fn from(value: EIP2930Transaction) -> Self
Converts to this type from the input type.
Sourceimpl From<EIP4844Transaction> for GenericTransaction
impl From<EIP4844Transaction> for GenericTransaction
Sourcefn from(value: EIP4844Transaction) -> Self
fn from(value: EIP4844Transaction) -> Self
Converts to this type from the input type.
Sourceimpl From<EIP7702Transaction> for GenericTransaction
impl From<EIP7702Transaction> for GenericTransaction
Sourcefn from(value: EIP7702Transaction) -> Self
fn from(value: EIP7702Transaction) -> Self
Converts to this type from the input type.
Sourceimpl From<FeeTokenTransaction> for GenericTransaction
impl From<FeeTokenTransaction> for GenericTransaction
Sourcefn from(value: FeeTokenTransaction) -> Self
fn from(value: FeeTokenTransaction) -> Self
Converts to this type from the input type.
Sourceimpl From<LegacyTransaction> for GenericTransaction
impl From<LegacyTransaction> for GenericTransaction
Sourcefn from(value: LegacyTransaction) -> Self
fn from(value: LegacyTransaction) -> Self
Converts to this type from the input type.
Sourceimpl From<PrivilegedL2Transaction> for GenericTransaction
impl From<PrivilegedL2Transaction> for GenericTransaction
Sourcefn from(value: PrivilegedL2Transaction) -> Self
fn from(value: PrivilegedL2Transaction) -> Self
Converts to this type from the input type.
Sourceimpl From<Transaction> for GenericTransaction
impl From<Transaction> for GenericTransaction
Sourcefn from(value: Transaction) -> Self
fn from(value: Transaction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for GenericTransaction
impl PartialEq for GenericTransaction
Sourcefn eq(&self, other: &GenericTransaction) -> bool
fn eq(&self, other: &GenericTransaction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GenericTransaction
Sourceimpl TryFrom<GenericTransaction> for EIP1559Transaction
impl TryFrom<GenericTransaction> for EIP1559Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericTransaction> for EIP4844Transaction
impl TryFrom<GenericTransaction> for EIP4844Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericTransaction> for EIP7702Transaction
impl TryFrom<GenericTransaction> for EIP7702Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericTransaction> for PrivilegedL2Transaction
impl TryFrom<GenericTransaction> for PrivilegedL2Transaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericTransaction> for FeeTokenTransaction
impl TryFrom<GenericTransaction> for FeeTokenTransaction
Sourcetype Error = GenericTransactionError
type Error = GenericTransactionError
The type returned in the event of a conversion error.