pub struct LegacyTransaction {
pub nonce: u64,
pub gas_price: U256,
pub gas: u64,
pub to: TxKind,
pub value: U256,
pub data: Bytes,
pub v: U256,
pub r: U256,
pub s: U256,
pub inner_hash: OnceCell<H256>,
pub sender_cache: OnceCell<Address>,
}Fields
nonce: u64gas_price: U256gas: u64to: TxKindThe recipient of the transaction.
Create transactions contain a null value in this field.
value: U256data: Bytesv: U256r: U256s: U256inner_hash: OnceCell<H256>sender_cache: OnceCell<Address>Trait Implementations
Sourceimpl Archive for LegacyTransactionwhere
u64: Archive,
U256Wrapper: ArchiveWith<U256>,
TxKind: Archive,
BytesWrapper: ArchiveWith<Bytes>,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>>,
impl Archive for LegacyTransactionwhere
u64: Archive,
U256Wrapper: ArchiveWith<U256>,
TxKind: Archive,
BytesWrapper: ArchiveWith<Bytes>,
Skip: ArchiveWith<OnceCell<H256>> + ArchiveWith<OnceCell<Address>>,
Sourcetype Archived = ArchivedLegacyTransaction
type Archived = ArchivedLegacyTransaction
The archived representation of this type. Read more
Sourcetype Resolver = LegacyTransactionResolver
type Resolver = LegacyTransactionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for LegacyTransaction
impl Clone for LegacyTransaction
Sourcefn clone(&self) -> LegacyTransaction
fn clone(&self) -> LegacyTransaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LegacyTransaction
impl Debug for LegacyTransaction
Sourceimpl Default for LegacyTransaction
impl Default for LegacyTransaction
Sourcefn default() -> LegacyTransaction
fn default() -> LegacyTransaction
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LegacyTransaction
impl<'de> Deserialize<'de> for LegacyTransaction
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<LegacyTransaction, __D> for Archived<LegacyTransaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
TxKind: Archive,
<TxKind as Archive>::Archived: Deserialize<TxKind, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<LegacyTransaction, __D> for Archived<LegacyTransaction>where
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
U256Wrapper: ArchiveWith<U256> + DeserializeWith<<U256Wrapper as ArchiveWith<U256>>::Archived, U256, __D>,
TxKind: Archive,
<TxKind as Archive>::Archived: Deserialize<TxKind, __D>,
BytesWrapper: ArchiveWith<Bytes> + DeserializeWith<<BytesWrapper as ArchiveWith<Bytes>>::Archived, Bytes, __D>,
Skip: ArchiveWith<OnceCell<H256>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<H256>>>::Archived, OnceCell<H256>, __D> + ArchiveWith<OnceCell<Address>> + DeserializeWith<<Skip as ArchiveWith<OnceCell<Address>>>::Archived, OnceCell<Address>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<LegacyTransaction, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<LegacyTransaction, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for LegacyTransaction
Sourceimpl From<LegacyTransaction> for GenericTransaction
impl From<LegacyTransaction> for GenericTransaction
Sourcefn from(value: LegacyTransaction) -> Self
fn from(value: LegacyTransaction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for LegacyTransaction
impl PartialEq for LegacyTransaction
Sourcefn eq(&self, other: &LegacyTransaction) -> bool
fn eq(&self, other: &LegacyTransaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PayloadRLPEncode for LegacyTransaction
impl PayloadRLPEncode for LegacyTransaction
fn encode_payload(&self, buf: &mut dyn BufMut)
fn encode_payload_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl RLPDecode for LegacyTransaction
impl RLPDecode for LegacyTransaction
fn decode_unfinished( rlp: &[u8], ) -> Result<(LegacyTransaction, &[u8]), RLPDecodeError>
fn decode(rlp: &[u8]) -> Result<Self, RLPDecodeError>
Sourceimpl RLPEncode for LegacyTransaction
impl RLPEncode for LegacyTransaction
Sourceimpl Serialize for LegacyTransaction
impl Serialize for LegacyTransaction
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for LegacyTransactionwhere
u64: Serialize<__S>,
U256Wrapper: SerializeWith<U256, __S>,
TxKind: Serialize<__S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for LegacyTransactionwhere
u64: Serialize<__S>,
U256Wrapper: SerializeWith<U256, __S>,
TxKind: Serialize<__S>,
BytesWrapper: SerializeWith<Bytes, __S>,
Skip: SerializeWith<OnceCell<H256>, __S> + SerializeWith<OnceCell<Address>, __S>,
impl StructuralPartialEq for LegacyTransaction