Module utils

Module utils 

Constants

ZERO_U256

Functions

decode_hex
keccak
truncate_array
Truncates an array of size N to size M. Fails compilation if N < M.
u256_from_big_endian
Converts a big endian slice to a u256, faster than u256::from_big_endian.
u256_from_big_endian_const
Converts a constant big endian slice to a u256, faster than u256::from_big_endian and u256_from_big_endian.
u256_to_big_endian
Converts a U256 to a big endian slice.
u256_to_h256