pub fn validate_requests_hash(
header: &BlockHeader,
chain_config: &ChainConfig,
requests: &[Requests],
) -> Result<(), InvalidBlockError>Expand description
Validates that the requests hash matches the block header (Prague+).
pub fn validate_requests_hash(
header: &BlockHeader,
chain_config: &ChainConfig,
requests: &[Requests],
) -> Result<(), InvalidBlockError>Validates that the requests hash matches the block header (Prague+).