Crate ethrex_common

Crate ethrex_common 

Re-exports

pub use errors::InvalidBlockError;
pub use validation::get_total_blob_gas;
pub use validation::validate_block_access_list_hash;
pub use validation::validate_block_access_list_size;
pub use validation::validate_block_pre_execution;
pub use validation::validate_gas_used;
pub use validation::validate_header_bal_indices;
pub use validation::validate_receipts_root_and_logs_bloom;
pub use validation::validate_requests_hash;

Modules

base64
base64 decoder/encoder using safe alphabet according to: https://datatracker.ietf.org/doc/html/rfc4648#section-4 https://datatracker.ietf.org/doc/html/rfc4648#section-5
constants
errors
evm
fd_limit
genesis_utils
rkyv_utils
serde_utils
tracing
Trace data types and their wire-format serializers.
types
utils
validation
Stateless block validation utilities.

Macros

if_ethbloom
Conditional compilation depending on whether ethereum-types is built with ethbloom support.

Structs

Bloom
Bloom hash type with 256 bytes (2048 bits) size.
BloomRef
Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
FromStrRadixErr
The error type for parsing numbers from strings.
H32
H64
H128
Fixed-size uninterpreted hash type with 16 bytes (128 bits) size.
H160
Fixed-size uninterpreted hash type with 20 bytes (160 bits) size.
H256
Fixed-size uninterpreted hash type with 32 bytes (256 bits) size.
H264
H512
Fixed-size uninterpreted hash type with 64 bytes (512 bits) size.
H520
NativeCrypto
Native crypto implementation using system libraries.
TrieLogger
U64
Little-endian large integer type Unsigned 64-bit integer.
U128
Little-endian large integer type 128-bit unsigned integer.
U256
Little-endian large integer type 256-bit unsigned integer.
U512
Little-endian large integer type 512-bits unsigned integer.

Enums

BloomInput
CryptoError
Errors from crypto operations. Opaque — does not leak library-specific types.
FromDecStrErr
Conversion from decimal string error
FromStrRadixErrKind
A list of error categories encountered when parsing numbers.

Traits

BigEndianHash

Type Aliases

Address
Public
Secret
Signature
TrieWitness